@@ -57,18 +57,18 @@ class MVNMixtureModel():
             "clusters":None, "var_constr":None, "is_computed":None}
         
         self.hyperparameters = { \
-            "mean_scale":min(self.dataset.float().var(), torch.tensor(1000).float()), \
+            "mean_scale":self.dataset.float().var().sqrt() * 1.5, \
             "mean_loc":self.dataset.float().max() / 2, \
             
             # mean and sd for the Normal prior of the variance
-            "var_loc":torch.tensor(120).float(), \
-            "var_scale":torch.tensor(130).float(), \
+            "var_loc":torch.tensor(140).float(), \
+            "var_scale":torch.tensor(185).float(), \
             "min_var":torch.tensor(5).float(), \
             
             "eta":torch.tensor(1).float(), \
             
             # slope and intercepts for the variance constraints
-            "slope":torch.tensor(0.15914).float(), "intercept":torch.tensor(23.70988).float()}
+            "slope":torch.tensor(0.179).float(), "intercept":torch.tensor(37.21).float()}
             # "slope":0.09804862, "intercept":22.09327233}
 
         self._autoguide = False
@@ -499,7 +499,7 @@ class MVNMixtureModel():
 
     def fit(self, steps=500, optim_fn=pyro.optim.Adam, loss_fn=pyro.infer.TraceEnum_ELBO(), \
             lr=0.005, cov_type="full", check_conv=True, p=1,  min_steps=1, default_lm=True, \
-            store_params=False, show_progr=True, seed_optim=True, seed=5, init_seed=None):
+            store_params=False, show_progr=True, seed_optim=True, seed=5, init_seed=5):
         
         pyro.enable_validation(True)
 
